@@ -1,3 +1,5 @@
+from typing import Optional
+
 from pyblustream.listener import MultiplexingListener
 from pyblustream.protocol import MatrixProtocol
 
@@ -11,16 +13,19 @@ class Matrix:
     def connect(self):
         self._protocol.connect()
 
-    def change_source(self, input_id, output_id):
+    def close(self):
+        self._protocol.close()
+
+    def change_source(self, input_id: int, output_id: int):
         self._protocol.send_change_source(input_id, output_id)
 
     def update_status(self):
         self._protocol.send_status_message()
 
-    def status_of_output(self, output_id):
+    def status_of_output(self, output_id: int) -> Optional[int]:
         return self._protocol.get_status_of_output(output_id)
 
-    def status_of_all_outputs(self):
+    def status_of_all_outputs(self) -> list[tuple[int, Optional[int]]]:
         return self._protocol.get_status_of_all_outputs()
 
     def turn_on(self):
